def func():
    for _ in range(5):
        pass
